==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/EmailConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EmailConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigBuilder>{
  public EmailConfigBuilder() {
    this(false);
  }
  public EmailConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new EmailConfig(), validationEnabled);
  }
  public EmailConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public EmailConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EmailConfig(), validationEnabled);
  }
  public EmailConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfig instance) {
    this(fluent, instance, false);
  }
  public EmailConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthIdentity(instance.getAuthIdentity()); 
    fluent.withAuthPassword(instance.getAuthPassword()); 
    fluent.withAuthSecret(instance.getAuthSecret()); 
    fluent.withAuthUsername(instance.getAuthUsername()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withHeaders(instance.getHeaders()); 
    fluent.withHello(instance.getHello()); 
    fluent.withHtml(instance.getHtml()); 
    fluent.withRequireTLS(instance.getRequireTLS()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withSmarthost(instance.getSmarthost()); 
    fluent.withText(instance.getText()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withTo(instance.getTo()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EmailConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfig instance) {
    this(instance,false);
  }
  public EmailConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthIdentity(instance.getAuthIdentity()); 
    this.withAuthPassword(instance.getAuthPassword()); 
    this.withAuthSecret(instance.getAuthSecret()); 
    this.withAuthUsername(instance.getAuthUsername()); 
    this.withFrom(instance.getFrom()); 
    this.withHeaders(instance.getHeaders()); 
    this.withHello(instance.getHello()); 
    this.withHtml(instance.getHtml()); 
    this.withRequireTLS(instance.getRequireTLS()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withSmarthost(instance.getSmarthost()); 
    this.withText(instance.getText()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withTo(instance.getTo()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.EmailConfig build() {
    EmailConfig buildable = new EmailConfig(fluent.getAuthIdentity(),fluent.getAuthPassword(),fluent.getAuthSecret(),fluent.getAuthUsername(),fluent.getFrom(),fluent.getHeaders(),fluent.getHello(),fluent.getHtml(),fluent.getRequireTLS(),fluent.getSendResolved(),fluent.getSmarthost(),fluent.getText(),fluent.getTlsConfig(),fluent.getTo());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EmailConfigBuilder that = (EmailConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/EmailConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EmailConfigBuilder extends EmailConfigFluentImpl<EmailConfigBuilder> implements VisitableBuilder<EmailConfig,EmailConfigBuilder>{
  public EmailConfigBuilder() {
    this(false);
  }
  public EmailConfigBuilder(Boolean validationEnabled) {
    this(new EmailConfig(), validationEnabled);
  }
  public EmailConfigBuilder(EmailConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public EmailConfigBuilder(EmailConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EmailConfig(), validationEnabled);
  }
  public EmailConfigBuilder(EmailConfigFluent<?> fluent,EmailConfig instance) {
    this(fluent, instance, false);
  }
  public EmailConfigBuilder(EmailConfigFluent<?> fluent,EmailConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthIdentity(instance.getAuthIdentity()); 
    fluent.withAuthPassword(instance.getAuthPassword()); 
    fluent.withAuthSecret(instance.getAuthSecret()); 
    fluent.withAuthUsername(instance.getAuthUsername()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withHeaders(instance.getHeaders()); 
    fluent.withHello(instance.getHello()); 
    fluent.withHtml(instance.getHtml()); 
    fluent.withRequireTLS(instance.getRequireTLS()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withSmarthost(instance.getSmarthost()); 
    fluent.withText(instance.getText()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withTo(instance.getTo()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EmailConfigBuilder(EmailConfig instance) {
    this(instance,false);
  }
  public EmailConfigBuilder(EmailConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthIdentity(instance.getAuthIdentity()); 
    this.withAuthPassword(instance.getAuthPassword()); 
    this.withAuthSecret(instance.getAuthSecret()); 
    this.withAuthUsername(instance.getAuthUsername()); 
    this.withFrom(instance.getFrom()); 
    this.withHeaders(instance.getHeaders()); 
    this.withHello(instance.getHello()); 
    this.withHtml(instance.getHtml()); 
    this.withRequireTLS(instance.getRequireTLS()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withSmarthost(instance.getSmarthost()); 
    this.withText(instance.getText()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withTo(instance.getTo()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  EmailConfigFluent<?> fluent;
  Boolean validationEnabled;
  public EmailConfig build() {
    EmailConfig buildable = new EmailConfig(fluent.getAuthIdentity(),fluent.getAuthPassword(),fluent.getAuthSecret(),fluent.getAuthUsername(),fluent.getFrom(),fluent.getHeaders(),fluent.getHello(),fluent.getHtml(),fluent.getRequireTLS(),fluent.getSendResolved(),fluent.getSmarthost(),fluent.getText(),fluent.getTlsConfig(),fluent.getTo());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
